@@ -5,6 +5,7 @@ from dataclasses import dataclass
 
 @dataclass(kw_only=True)
 class DraftPick:
+    draft_id: int
     owner_id: int
     previous_owner_id: int
     roster_id: int
@@ -17,7 +18,8 @@ class DraftPick:
                          round=draft_pick_dict.get("round"),
                          roster_id=draft_pick_dict.get("roster_id"),
                          previous_owner_id=draft_pick_dict.get("previous_owner_id"),
-                         owner_id=draft_pick_dict.get("owner_id"))
+                         owner_id=draft_pick_dict.get("owner_id"),
+                         draft_id=draft_pick_dict.get("draft_id"))
 
     @classmethod
     def from_dict_list(cls, draft_pick_dict_list: dict) -> list[DraftPick]:
